__all__ = ["FeatureEncoder"]


class FeatureEncoder:
    r"""Class for implementing feature encoders.

    Date:
        2020

    Author:
        Luka Pečnik

    License:
        MIT

    Attributes:
        Name (str): Name of the feature encoder.
    """
    Name = None

    def __init__(self, **kwargs):
        r"""Initialize feature encoder."""
        return None

    def fit(self, feature):
        r"""Fit feature encoder.

        Arguments:
            feature (pandas.core.frame.DataFrame): A column (categorical) from DataFrame of features.
        """
        return None

    def transform(self, feature):
        r"""Transform feature's values.

        Arguments:
            feature (pandas.core.frame.DataFrame): A column (categorical) from DataFrame of features.

        Returns:
            pandas.core.frame.DataFrame: A transformed column.
        """
        return None

    def to_string(self):
        r"""User friendly representation of the object.

        Returns:
            str: User friendly representation of the object.
        """
        return "{name}"



from niaaml.preprocessing.encoding.feature_encoder import FeatureEncoder
from sklearn.preprocessing import OneHotEncoder as OHE
import pandas as pd

__all__ = ["OneHotEncoder"]


class OneHotEncoder(FeatureEncoder):
    r"""Implementation of one-hot encoder.

    Date:
        2020

    Author:
        Luka Pečnik

    License:
        MIT

    Reference:
        Seger, Cedric. "An investigation of categorical variable encoding techniques in machine learning: binary versus one-hot and feature hashing." (2018).

    Documentation:
        https://scikit-learn.org/stable/modules/generated/sklearn.preprocessing.OneHotEncoder.html

    See Also:
        * :class:`niaaml.preprocessing.encoding.FeatureEncoder`
    """
    Name = "One-Hot Encoder"

    def __init__(self, **kwargs):
        r"""Initialize feature encoder."""
        self.__one_hot_encoder = OHE(handle_unknown="ignore")

    def fit(self, feature):
        r"""Fit feature encoder.

        Arguments:
            feature (pandas.core.frame.DataFrame): A column (categorical) from DataFrame of features.
        """
        self.__one_hot_encoder.fit(feature)

    def transform(self, feature):
        r"""Transform feature's values.

        Arguments:
            feature (pandas.core.frame.DataFrame): A column (categorical) from DataFrame of features.

        Returns:
            pandas.core.frame.DataFrame: A transformed column.
        """
        return pd.DataFrame(self.__one_hot_encoder.transform(feature).toarray())

    def to_string(self):
        r"""User friendly representation of the object.

        Returns:
            str: User friendly representation of the object.
        """
        return FeatureEncoder.to_string(self).format(name=self.Name)



import pandas as pd
from niaaml.data.data_reader import DataReader

__all__ = ["CSVDataReader"]


class CSVDataReader(DataReader):
    r"""Implementation of CSV data reader.

    Date:
        2020

    Author:
        Luka Pečnik

    License:
        MIT

    Attributes:
        __src (string): Path to a CSV file.
        __contains_classes (bool): Tells if src contains expected classification results or only features.
        __has_header (bool): Tells if src contains header row.

    See Also:
        * :class:`niaaml.data.DataReader`
    """

    def _set_parameters(self, src, contains_classes=True, has_header=False, **kwargs):
        r"""Set the parameters of the algorithm.

        Arguments:
            src (string): Path to a CSV dataset file.
            contains_classes (Optional[bool]): Tells if src contains expected classification results or only features.
            has_header (Optional[bool]): Tells if src contains header row.
        """
        self.__src = src
        self.__contains_classes = contains_classes
        self.__has_header = has_header
        self._read_data()

    def _read_data(self, **kwargs):
        r"""Read data from expected source."""
        data = pd.read_csv(
            self.__src, header=None if self.__has_header is False else "infer"
        )
        header = data.columns

        if self.__contains_classes:
            self._y = data.pop(header[len(header) - 1])

        self._x = data



from sklearn.impute import SimpleImputer as SI
from niaaml.preprocessing.imputation.imputer import Imputer
import numpy as np
import pandas as pd

__all__ = ["SimpleImputer"]


class SimpleImputer(Imputer):
    r"""Implementation of simple imputer.

    Date:
        2020

    Author:
        Luka Pečnik

    License:
        MIT

    Documentation:
        https://scikit-learn.org/stable/modules/generated/sklearn.impute.SimpleImputer.html

    See Also:
        * :class:`niaaml.preprocessing.imputation.Imputer`
    """
    Name = "Simple Imputer"

    def __init__(self, **kwargs):
        r"""Initialize imputer."""
        self.__simple_imputer = SI(missing_values=np.nan)

    def fit(self, feature):
        r"""Fit imputer.

        Arguments:
            feature (pandas.core.frame.DataFrame): A column from DataFrame of features.
        """
        if not pd.api.types.is_numeric_dtype(feature.iloc[:, 0]):
            replacement_val = feature.mode().iloc[0, 0]
            self.__simple_imputer.set_params(
                **{"fill_value": replacement_val, "strategy": "constant"}
            )
            self.__simple_imputer.fit(feature)
        else:
            self.__simple_imputer.fit(feature)

    def transform(self, feature):
        r"""Transform feature's values.

        Arguments:
            feature (pandas.core.frame.DataFrame): A column from DataFrame of features.

        Returns:
            pandas.core.frame.DataFrame: A transformed column.
        """
        return self.__simple_imputer.transform(feature)

    def to_string(self):
        r"""User friendly representation of the object.

        Returns:
            str: User friendly representation of the object.
        """
        return Imputer.to_string(self).format(name=self.Name)



from niaaml.classifiers.classifier import Classifier
from niaaml.utilities import MinMax
from niaaml.utilities import ParameterDefinition
from sklearn.ensemble import ExtraTreesClassifier
import numpy as np

import warnings
from sklearn.exceptions import (
    ConvergenceWarning,
    DataConversionWarning,
    DataDimensionalityWarning,
    EfficiencyWarning,
    FitFailedWarning,
    UndefinedMetricWarning,
)

__all__ = ["ExtremelyRandomizedTrees"]


class ExtremelyRandomizedTrees(Classifier):
    r"""Implementation of extremely randomized trees classifier.

    Date:
        2020

    Author:
        Luka Pečnik

    License:
        MIT

    Reference:
        P. Geurts, D. Ernst., and L. Wehenkel, “Extremely randomized trees”, Machine Learning, 63(1), 3-42, 2006.

    Documentation:
        https://scikit-learn.org/stable/modules/generated/sklearn.ensemble.ExtraTreesClassifier.html

    See Also:
        * :class:`niaaml.classifiers.Classifier`
    """
    Name = "Extremely Randomized Trees"

    def __init__(self, **kwargs):
        r"""Initialize ExtremelyRandomizedTrees instance."""
        warnings.filterwarnings(action="ignore", category=ConvergenceWarning)
        warnings.filterwarnings(action="ignore", category=DataConversionWarning)
        warnings.filterwarnings(action="ignore", category=DataDimensionalityWarning)
        warnings.filterwarnings(action="ignore", category=EfficiencyWarning)
        warnings.filterwarnings(action="ignore", category=FitFailedWarning)
        warnings.filterwarnings(action="ignore", category=UndefinedMetricWarning)

        self._params = dict(
            n_estimators=ParameterDefinition(MinMax(min=10, max=111), np.uint)
        )
        self.__extra_trees_classifier = ExtraTreesClassifier()

    def set_parameters(self, **kwargs):
        r"""Set the parameters/arguments of the algorithm."""
        self.__extra_trees_classifier.set_params(**kwargs)

    def fit(self, x, y, **kwargs):
        r"""Fit ExtremelyRandomizedTrees.

        Arguments:
            x (pandas.core.frame.DataFrame): n samples to classify.
            y (pandas.core.series.Series): n classes of the samples in the x array.

        Returns:
            None
        """
        self.__extra_trees_classifier.fit(x, y)

    def predict(self, x, **kwargs):
        r"""Predict class for each sample (row) in x.

        Arguments:
            x (pandas.core.frame.DataFrame): n samples to classify.

        Returns:
            pandas.core.series.Series: n predicted classes.
        """
        return self.__extra_trees_classifier.predict(x)

    def to_string(self):
        r"""User friendly representation of the object.

        Returns:
            str: User friendly representation of the object.
        """
        return Classifier.to_string(self).format(
            name=self.Name,
            args=self._parameters_to_string(self.__extra_trees_classifier.get_params()),
        )



from niaaml.preprocessing.feature_selection.feature_selection_algorithm import (
    FeatureSelectionAlgorithm,
)
from niaaml.preprocessing.feature_selection.variance_threshold import VarianceThreshold
from niaaml.preprocessing.feature_selection.jDEFSTH import jDEFSTH
from niaaml.preprocessing.feature_selection.select_percentile import SelectPercentile
from niaaml.preprocessing.feature_selection.select_k_best import SelectKBest
from niaaml.preprocessing.feature_selection.particle_swarm_optimization import (
    ParticleSwarmOptimization,
)
from niaaml.preprocessing.feature_selection.bat_algorithm import BatAlgorithm
from niaaml.preprocessing.feature_selection.differential_evolution import (
    DifferentialEvolution,
)
from niaaml.preprocessing.feature_selection.grey_wolf_optimizer import GreyWolfOptimizer
from niaaml.preprocessing.feature_selection.utility import (
    FeatureSelectionAlgorithmFactory,
)
from niaaml.preprocessing.feature_selection._feature_selection_threshold_problem import (
    _FeatureSelectionThresholdProblem,
)

__all__ = [
    "FeatureSelectionAlgorithm",
    "VarianceThreshold",
    "jDEFSTH",
    "SelectPercentile",
    "ParticleSwarmOptimization",
    "BatAlgorithm",
    "DifferentialEvolution",
    "GreyWolfOptimizer",
    "SelectKBest",
    "FeatureSelectionAlgorithmFactory",
    "_FeatureSelectionThresholdProblem",
]



from niaaml.utilities import Factory
import pandas as pd
from niaaml.preprocessing.encoding.one_hot_encoder import OneHotEncoder

__all__ = ["encode_categorical_features", "EncoderFactory"]


def encode_categorical_features(features, encoder):
    """Encode categorical features.

    Arguments:
        features (pandas.core.frame.DataFrame): DataFrame of features.
        encoder (str): Name of the encoder to use.

    Returns:
                Tuple[pandas.core.frame.DataFrame, Iterable[FeatureEncoder]]:
                        1. Converted dataframe.
                        2. Dictionary of encoders for all categorical features.
    """
    enc = EncoderFactory().get_result(encoder)

    encoders = {}
    to_drop = []
    enc_features = pd.DataFrame()
    cols = [
        col
        for col in features.columns
        if not pd.api.types.is_numeric_dtype(features[col])
    ]
    for c in cols:
        enc.fit(features[[c]])
        tr = enc.transform(features[[c]])
        to_drop.append(c)
        enc_features = pd.concat([enc_features, tr], axis=1)
        encoders[c] = enc
    features = features.drop(to_drop, axis=1)
    features = pd.concat([features, enc_features], axis=1)
    return features, encoders if len(encoders) > 0 else None


class EncoderFactory(Factory):
    r"""Class with string mappings to encoders.

    Attributes:
        _entities (Dict[str, FeatureEncoder]): Mapping from strings to encoders.

    See Also:
        * :class:`niaaml.utilities.Factory`
    """

    def _set_parameters(self, **kwargs):
        r"""Set the parameters/arguments of the factory."""
        self._entities = {"OneHotEncoder": OneHotEncoder}



from niaaml.utilities import Factory
from niaaml.preprocessing.feature_transform.normalizer import Normalizer
from niaaml.preprocessing.feature_transform.standard_scaler import StandardScaler
from niaaml.preprocessing.feature_transform.max_abs_scaler import MaxAbsScaler
from niaaml.preprocessing.feature_transform.quantile_transformer import (
    QuantileTransformer,
)
from niaaml.preprocessing.feature_transform.robust_scaler import RobustScaler

__all__ = ["FeatureTransformAlgorithmFactory"]


class FeatureTransformAlgorithmFactory(Factory):
    r"""Class with string mappings to feature transform algorithms.

    Attributes:
        _entities (Dict[str, FeatureTransformAlgorithm]): Mapping from strings to feature transform algorithms.
    """

    def _set_parameters(self, **kwargs):
        r"""Set the parameters/arguments of the factory."""
        self._entities = {
            "Normalizer": Normalizer,
            "StandardScaler": StandardScaler,
            "MaxAbsScaler": MaxAbsScaler,
            "QuantileTransformer": QuantileTransformer,
            "RobustScaler": RobustScaler,
        }



from niaaml.preprocessing.feature_transform.feature_transform_algorithm import (
    FeatureTransformAlgorithm,
)
from niaaml.preprocessing.feature_transform.normalizer import Normalizer
from niaaml.preprocessing.feature_transform.standard_scaler import StandardScaler
from niaaml.preprocessing.feature_transform.max_abs_scaler import MaxAbsScaler
from niaaml.preprocessing.feature_transform.quantile_transformer import (
    QuantileTransformer,
)
from niaaml.preprocessing.feature_transform.robust_scaler import RobustScaler
from niaaml.preprocessing.feature_transform.utility import (
    FeatureTransformAlgorithmFactory,
)

__all__ = [
    "FeatureTransformAlgorithm",
    "Normalizer",
    "StandardScaler",
    "MaxAbsScaler",
    "RobustScaler",
    "FeatureTransformAlgorithmFactory",
    "QuantileTransformer",
]



from niaaml import classifiers
from niaaml import data
from niaaml import preprocessing
from niaaml import fitness
from niaaml.utilities import MinMax
from niaaml.utilities import ParameterDefinition
from niaaml.utilities import Factory
from niaaml.utilities import OptimizationStats
from niaaml.utilities import get_bin_index
from niaaml.pipeline_optimizer import PipelineOptimizer
from niaaml.pipeline import Pipeline
from niaaml.pipeline_component import PipelineComponent
from niaaml.logger import Logger

__all__ = [
    "classifiers",
    "data",
    "preprocessing",
    "fitness",
    "get_bin_index",
    "MinMax",
    "ParameterDefinition",
    "OptimizationStats",
    "Factory",
    "PipelineOptimizer",
    "Pipeline",
    "PipelineComponent",
    "Logger",
]

__project__ = "niaaml"
__version__ = "1.1.9"



from niaaml.pipeline_component import PipelineComponent

__all__ = ["PreprocessingAlgorithm"]


class PreprocessingAlgorithm(PipelineComponent):
    r"""Class for implementing preprocessing algorithms.

    Date:
        2020

    Author:
        Luka Pečnik

    License:
        MIT

    See Also:
        * :class:`niaaml.pipeline_component.PipelineComponent`
    """



from niaaml.preprocessing.preprocessing_algorithm import PreprocessingAlgorithm

__all__ = ["FeatureTransformAlgorithm"]


class FeatureTransformAlgorithm(PreprocessingAlgorithm):
    r"""Class for implementing feature transform algorithms.

    Date:
        2020

    Author:
        Luka Pečnik

    License:
        MIT

    See Also:
        * :class:`niaaml.preprocessing.preprocessing_algorithm.PreprocessingAlgorithm`
    """

    def fit(self, x, **kwargs):
        r"""Fit implemented feature transform algorithm.

        Arguments:
            x (pandas.core.frame.DataFrame): n samples to fit transformation algorithm.
        """
        return

    def transform(self, x, **kwargs):
        r"""Transforms the given x data.

        Arguments:
            x (pandas.core.frame.DataFrame): Data to transform.

        Returns:
            pandas.core.frame.DataFrame: Transformed data.
        """
        return x



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['niaaml',
 'niaaml.classifiers',
 'niaaml.data',
 'niaaml.fitness',
 'niaaml.preprocessing',
 'niaaml.preprocessing.encoding',
 'niaaml.preprocessing.feature_selection',
 'niaaml.preprocessing.feature_transform',
 'niaaml.preprocessing.imputation']

package_data = \
{'': ['*']}

install_requires = \
['niapy>=2.0.0,<3.0.0',
 'numpy>=1.19.1,<2.0.0',
 'pandas>=1.1.4,<2.0.0',
 'scikit-learn>=0.23.2,<0.24.0']

setup_kwargs = {
    'name': 'niaaml',
    'version': '1.1.9',
    'description': 'Python automated machine learning framework.',
    'long_description': "NiaAML\n======\n\n.. image:: https://github.com/lukapecnik/niaaml/actions/workflows/test.yml/badge.svg\n    :target: https://github.com/lukapecnik/niaaml\n\n.. image:: https://coveralls.io/repos/github/lukapecnik/NiaAML/badge.svg?branch=travisCI_integration\n    :target: https://coveralls.io/github/lukapecnik/NiaAML?branch=travisCI_integration\n\n.. image:: https://img.shields.io/pypi/v/niaaml.svg\n    :target: https://pypi.python.org/pypi/niaaml\n\n.. image:: https://img.shields.io/pypi/pyversions/niaaml.svg\n    :target: https://pypi.org/project/NiaPy/\n\n.. image:: https://img.shields.io/github/license/lukapecnik/niaaml.svg\n    :target: https://github.com/lukapecnik/niaaml/blob/master/LICENSE\n\n.. image:: https://zenodo.org/badge/289322337.svg\n   :target: https://zenodo.org/badge/latestdoi/289322337\n\n.. image:: https://joss.theoj.org/papers/10.21105/joss.02949/status.svg\n   :target: https://doi.org/10.21105/joss.02949\n\nNiaAML is an automated machine learning Python framework based on\nnature-inspired algorithms for optimization. The name comes from the\nautomated machine learning method of the same name [1]. Its\ngoal is to efficiently compose the best possible classification pipeline\nfor the given task using components on the input. The components are\ndivided into three groups: feature seletion algorithms, feature\ntransformation algorithms and classifiers. The framework uses\nnature-inspired algorithms for optimization to choose the best set of\ncomponents for the classification pipeline on the output and optimize\ntheir parameters. We use `NiaPy framework <https://github.com/NiaOrg/NiaPy>`_ for the optimization process\nwhich is a popular Python collection of nature-inspired algorithms. The\nNiaAML framework is easy to use and customize or expand to suit your\nneeds.\n\nThe NiaAML framework allows you not only to run full pipeline optimization, but also separate implemented components such as classifiers, feature selection algorithms, etc. **It supports numerical and categorical features as well as missing values in datasets.**\n\n- **Documentation:** https://niaaml.readthedocs.io/en/latest/,\n- **Tested OS:** Windows, Ubuntu, Fedora, Linux Mint and CentOS. **However, that does not mean it does not work on others.**\n\nInstallation\n------------\n\npip\n~~~\n\nInstall NiaAML with pip3:\n\n.. code:: sh\n\n    pip3 install niaaml\n\nIn case you would like to try out the latest pre-release version of the framework, install it using:\n\n.. code:: sh\n\n    pip3 install niaaml --pre\n\nGraphical User Interface\n------------------------\n\nYou can find a simple graphical user interface for NiaAML package `here <https://github.com/lukapecnik/NiaAML-GUI>`_.\n\nUsage\n-----\n\nSee the project's `repository <https://github.com/lukapecnik/NiaAML>`_ for usage examples.\n\nComponents\n----------\n\nIn the following sections you can see a list of currently implemented \ncomponents divided into groups: classifiers, feature selection \nalgorithms and feature transformation algorithms. At the end you can \nalso see a list of currently implemented fitness functions for the optimization process, \ncategorical features' encoders, and missing values' imputers.\n\nClassifiers\n~~~~~~~~~~~\n\n-  Adaptive Boosting (AdaBoost),\n-  Bagging (Bagging),\n-  Extremely Randomized Trees (ExtremelyRandomizedTrees),\n-  Linear SVC (LinearSVC),\n-  Multi Layer Perceptron (MultiLayerPerceptron),\n-  Random Forest Classifier (RandomForest),\n-  Decision Tree Classifier (DecisionTree),\n-  K-Neighbors Classifier (KNeighbors),\n-  Gaussian Process Classifier (GaussianProcess),\n-  Gaussian Naive Bayes (GaussianNB),\n-  Quadratic Discriminant Analysis (QuadraticDiscriminantAnalysis).\n\nFeature Selection Algorithms\n~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n\n-  Select K Best (SelectKBest),\n-  Select Percentile (SelectPercentile),\n-  Variance Threshold (VarianceThreshold).\n\nNature-Inspired\n^^^^^^^^^^^^^^^\n\n-  Bat Algorithm (BatAlgorithm),\n-  Differential Evolution (DifferentialEvolution),\n-  Self-Adaptive Differential Evolution (jDEFSTH),\n-  Grey Wolf Optimizer (GreyWolfOptimizer),\n-  Particle Swarm Optimization (ParticleSwarmOptimization).\n\nFeature Transformation Algorithms\n~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n\n-  Normalizer (Normalizer),\n-  Standard Scaler (StandardScaler),\n-  Maximum Absolute Scaler (MaxAbsScaler),\n-  Quantile Transformer (QuantileTransformer),\n-  Robust Scaler (RobustScaler).\n\nFitness Functions based on\n~~~~~~~~~~~~~~~~~~~~~~~~~~\n\n-  Accuracy (Accuracy),\n-  Cohen's kappa (CohenKappa),\n-  F1-Score (F1),\n-  Precision (Precision).\n\nCategorical Feature Encoders\n~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n\n- One-Hot Encoder (OneHotEncoder).\n\nFeature Imputers\n~~~~~~~~~~~~~~~~\n\n- Simple Imputer (SimpleImputer).\n\nLicence\n-------\n\nThis package is distributed under the MIT License. This license can be\nfound online at http://www.opensource.org/licenses/MIT.\n\nDisclaimer\n----------\n\nThis framework is provided as-is, and there are no guarantees that it\nfits your purposes or that it is bug-free. Use it at your own risk!\n\nReferences\n----------\n\n[1] Iztok Fister Jr., Milan Zorman, Dušan Fister, Iztok Fister.\nContinuous optimizers for automatic design and evaluation of\nclassification pipelines. In: Frontier applications of nature inspired\ncomputation. Springer tracts in nature-inspired computing, pp.281-301,\n2020.\n",
    'author': 'Luka Pečnik',
    'author_email': 'lukapecnik96@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/lukapecnik/NiaAML',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6.2,<4.0.0',
}


setup(**setup_kwargs)



from niaaml.preprocessing.preprocessing_algorithm import PreprocessingAlgorithm
from niaaml.preprocessing import feature_selection
from niaaml.preprocessing import feature_transform
from niaaml.preprocessing import encoding
from niaaml.preprocessing import imputation

__all__ = [
    "feature_selection",
    "feature_transform",
    "encoding",
    "imputation",
    "PreprocessingAlgorithm",
]



import logging
import os


class Logger:
    r"""Class for logging throughout the framework.

    Date:
        2020

    Author:
        Luka Pečnik

    License:
        MIT
    """

    def __init__(self, verbose=False, output_file=None, **kwargs):
        r"""Initialize Logger.

        Arguments:
            verbose (Optional(bool)): If True, output verbose pipeline info.
            output_file (Optional(str)): If set, logger outputs content to a log file.
        """
        if output_file is not None:
            if (
                len(os.path.splitext(output_file)[1]) == 0
                or os.path.splitext(output_file)[1] != ".log"
            ):
                output_file = output_file + ".log"
        self.__logger = logging.getLogger("niaaml")
        self.__logger.setLevel(logging.INFO)

        if output_file is not None:
            fh = logging.FileHandler(output_file)
            self.__logger.addHandler(fh)

        self.__verbose = verbose

    def __del__(self):
        logging.shutdown()

    def log_progress(self, text):
        r"""Log progress message."""
        self.__logger.info(text)

    def log_pipeline(self, text):
        r"""Log pipeline info message."""
        if self.__verbose is True:
            self.__logger.info(text)

    def log_optimization_error(self, text):
        r"""Log optimization error message."""
        if self.__verbose is True:
            self.__logger.warning(text)



import pandas as pd
from niaaml.data.data_reader import DataReader

__all__ = ["BasicDataReader"]


class BasicDataReader(DataReader):
    r"""Implementation of basic data reader.

    Date:
        2020

    Author:
        Luka Pečnik

    License:
        MIT

    See Also:
        * :class:`niaaml.data.DataReader`
    """

    def _set_parameters(self, x, y=None, **kwargs):
        r"""Set the parameters of the algorithm.

        Arguments:
            x (Iterable[float]): Array of rows from dataset without expected classification results.
            y (Optional[Iterable[any]]): Array of expected classification results.
        """
        self._x = pd.DataFrame(x)

        if y is not None:
            self._y = pd.Series(y)



from niaaml.classifiers.classifier import Classifier
from niaaml.classifiers.random_forest import RandomForest
from niaaml.classifiers.multi_layer_perceptron import MultiLayerPerceptron
from niaaml.classifiers.linear_svc import LinearSVC
from niaaml.classifiers.ada_boost import AdaBoost
from niaaml.classifiers.extremely_randomized_trees import ExtremelyRandomizedTrees
from niaaml.classifiers.bagging import Bagging
from niaaml.classifiers.decision_tree import DecisionTree
from niaaml.classifiers.k_neighbors import KNeighbors
from niaaml.classifiers.gaussian_process import GaussianProcess
from niaaml.classifiers.gaussian_naive_bayes import GaussianNB
from niaaml.classifiers.quadratic_driscriminant_analysis import (
    QuadraticDiscriminantAnalysis,
)
from niaaml.classifiers.utility import ClassifierFactory

__all__ = [
    "Classifier",
    "RandomForest",
    "MultiLayerPerceptron",
    "LinearSVC",
    "AdaBoost",
    "Bagging",
    "ExtremelyRandomizedTrees",
    "DecisionTree",
    "KNeighbors",
    "GaussianProcess",
    "GaussianNB",
    "QuadraticDiscriminantAnalysis",
    "ClassifierFactory",
]
